==> xl-react-components-0.16.62.tgz: package/app/xl-react-dip/xl-react-dip-collection-of-ci/xl-react-dip-collection-of-ci-component.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import classNames from 'classnames';
import SortableList from '../sortable-list/sortable-list';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {validationMessageClasses} from '../../utils/css-utils';
import {XlReactWidgetAutocomplete} from '../../xl-react-widget/xl-react-widget-autocomplete/xl-react-widget-autocomplete'; // eslint-disable-line max-len
import {XlReactWidgetFilter} from '../../xl-react-widget/xl-react-widget-filter/xl-react-widget-filter';
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';

import './xl-react-dip-collection-of-ci.less';

export class XlReactDipCollectionOfCiComponent extends PureComponent {
    static propTypes = {
        filteredItems: PropTypes.array,
        filterVisible: PropTypes.bool,
        handleAddItem: PropTypes.func,
        handleFilterUpdate: PropTypes.func,
        handleModelChange: PropTypes.func,
        handleRemoveItem: PropTypes.func,
        handlers: PropTypes.object,
        inputVisible: PropTypes.bool,
        message: xlMessageTypeProp,
        metadata: PropTypes.object,
        model: PropTypes.array,
        objLabel: PropTypes.string,
        onValidityChange: PropTypes.func,
        readOnly: PropTypes.bool,
        registerAutoCompleteApi: PropTypes.func,
        searchTerm: PropTypes.string,
        sortable: PropTypes.bool,
        valid: PropTypes.bool
    };

    render() {
        const {
            message,
            filteredItems,
            filterVisible,
            handleFilterUpdate,
            handleModelChange,
            handleRemoveItem,
            handlers,
            handleAddItem,
            inputVisible,
            metadata,
            objLabel,
            readOnly,
            registerAutoCompleteApi,
            searchTerm,
            sortable,
            valid
        } = this.props;

        const inputFilter = (isVisible) =>
            isVisible ? <XlReactWidgetFilter model={searchTerm} onUpdate={handleFilterUpdate}/> : null;

        const dipInput = (isVisible) => {
            const autocompleteMetadata = R.omit(['default', 'description', 'label', 'required'], metadata);

            const dipInputClassName = classNames(
                'dip-input',
                validationMessageClasses(valid, message)
            );

            return isVisible ? <div className={dipInputClassName}>
                <XlReactWidgetAutocomplete
                    disabled={readOnly}
                    handlers={handlers}
                    metadata={autocompleteMetadata}
                    objLabel={objLabel}
                    onSuggestionSelected={handleAddItem}
                    register={registerAutoCompleteApi}
                />
            </div> : null;
        };

        const scrollablePanel = (listItems) => <div className="xl-scrollable-panel">
            <div>
                <SortableList
                    canSort={sortable && !readOnly && R.isEmpty(searchTerm)}
                    disabled={readOnly}
                    indexedItems={listItems}
                    onChange={handleModelChange}
                    remove={handleRemoveItem}
                />
            </div>
        </div>;

        const controlClass = classNames(
            {'xl-react-dip-collection-of-ci': true},
            validationMessageClasses(valid, message)
        );

        return <XlReactFormItemControl {...({
            ...metadata,
            controlClass,
            message
        })}>
            {dipInput(inputVisible)}
            {inputFilter(filterVisible)}
            {scrollablePanel(filteredItems)}
        </XlReactFormItemControl>;
    }
}

==> xl-react-components-0.18.103.tgz: package/app/xl-react-dip/xl-react-dip-collection-of-ci/xl-react-dip-collection-of-ci-component.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import classNames from 'classnames';
import SortableList from '../sortable-list/sortable-list';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {validationMessageClasses} from '../../utils/css-utils';
import {XlReactWidgetAutocomplete} from '../../xl-react-widget/xl-react-widget-autocomplete/xl-react-widget-autocomplete'; // eslint-disable-line max-len
import {XlReactWidgetFilter} from '../../xl-react-widget/xl-react-widget-filter/xl-react-widget-filter';
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';

import './xl-react-dip-collection-of-ci.less';

export class XlReactDipCollectionOfCiComponent extends PureComponent {
    static propTypes = {
        filterVisible: PropTypes.bool,
        handleAddItem: PropTypes.func,
        handleFilterUpdate: PropTypes.func,
        handleModelChange: PropTypes.func,
        handleRemoveItem: PropTypes.func,
        handlers: PropTypes.object,
        inputVisible: PropTypes.bool,
        message: xlMessageTypeProp,
        metadata: PropTypes.object,
        objLabel: PropTypes.string,
        onValidityChange: PropTypes.func,
        readOnly: PropTypes.bool,
        registerAutoCompleteApi: PropTypes.func,
        searchTerm: PropTypes.string,
        sortable: PropTypes.bool,
        valid: PropTypes.bool,
        visibleItems: PropTypes.array
    };

    render() {
        const {
            message,
            visibleItems,
            filterVisible,
            handleFilterUpdate,
            handleModelChange,
            handleRemoveItem,
            handlers,
            handleAddItem,
            inputVisible,
            metadata,
            objLabel,
            readOnly,
            registerAutoCompleteApi,
            searchTerm,
            sortable,
            valid
        } = this.props;

        const inputFilter = (isVisible) =>
            isVisible ? <XlReactWidgetFilter model={searchTerm} onUpdate={handleFilterUpdate}/> : null;

        const dipInput = (isVisible) => {
            const autocompleteMetadata = R.omit(['default', 'description', 'label', 'required'], metadata);

            const dipInputClassName = classNames(
                'dip-input',
                validationMessageClasses(valid, message)
            );

            return isVisible ? <div className={dipInputClassName}>
                <XlReactWidgetAutocomplete
                    disabled={readOnly}
                    handlers={handlers}
                    metadata={autocompleteMetadata}
                    objLabel={objLabel}
                    onSuggestionSelected={handleAddItem}
                    register={registerAutoCompleteApi}
                />
            </div> : null;
        };

        const scrollablePanel = (listItems) => <div className="xl-scrollable-panel">
            <div>
                <SortableList
                    canSort={sortable && !readOnly && R.isEmpty(searchTerm)}
                    disabled={readOnly}
                    indexedItems={listItems}
                    onChange={handleModelChange}
                    remove={handleRemoveItem}
                />
            </div>
        </div>;

        const controlClass = classNames(
            {'xl-react-dip-collection-of-ci': true},
            {'is-disabled': readOnly},
            validationMessageClasses(valid, message)
        );

        return <XlReactFormItemControl {...({
            ...metadata,
            controlClass,
            message
        })}>
            {dipInput(inputVisible)}
            {inputFilter(filterVisible)}
            {scrollablePanel(visibleItems)}
        </XlReactFormItemControl>;
    }
}
